require File.expand_path(File.dirname(__FILE__) + '/spec_helper')

describe SimpleConfig do
  it "should have 'config' as default directory" do
    SimpleConfig.directory.should == 'config'
  end

  it "should have 'config.yml' as default config file" do
    SimpleConfig.default.should == :config
  end

  describe "configuration file exists" do
    before :each do
      File.open( '/tmp/test.yml', 'w+' ) do |out|
        YAML.dump( {:key1 => "value1", :key2 => "value2"}, out )
      end

      SimpleConfig.directory = "/tmp"
    end

    it "should return SimpleStruct as file content" do
      SimpleConfig.test.should be_kind_of(SimpleStruct)
    end

    describe "default file" do
      before :each do
        SimpleConfig.default  = :test
      end

      it "should be accessed if there is no file with required property name" do
        SimpleConfig.key1.should == "value1"
      end
    end

    after :each do
      File.delete("/tmp/test.yml")
    end
  end

  describe "configuration file does not exist" do
    it "should raise exception" do
      lambda {
        SimpleConfig.some_wrong_file
      }.should raise_error
    end
  end
end
