require File.expand_path(File.dirname(__FILE__) + '/spec_helper')

describe SimpleStruct do
  describe "create" do
    it "should return Simple Struct if hash is passed as parameter" do
      SimpleStruct.create({ :key => "value" }).should be_kind_of(SimpleStruct)
    end

    it "should return the same value if passed value is not hash" do
      SimpleStruct.create("Some value").should == "Some value"
    end

    it "converts iternal hashed into the SimpleStructs" do
      SimpleStruct.create({ :key => "value", :key1 => {} })[:key1].should be_kind_of(SimpleStruct)
    end
  end

  describe "to_hash" do
    before :each do
      @simple_struct = SimpleStruct.create({ :key => "value", "str_key" => "value", :hash => {:inner_key => :inner_value} })
    end

  end

  describe "indexer" do
    before :each do
      @simple_struct = SimpleStruct.create({ :key => "value", "str_key" => "value" })
    end

    describe "read" do
      describe "existing key" do
        it "index - like" do
          @simple_struct[:key].should == "value"
          @simple_struct[:str_key].should == "value"
        end

        it "does not depends on key type" do
          @simple_struct["key"].should == "value"
          @simple_struct["str_key"].should == "value"
        end

        it "as property" do
          @simple_struct.key.should == "value"
          @simple_struct.str_key.should == "value"
        end
      end

      describe "not existing property" do
        it "return nil if accessed via indexer" do
          @simple_struct[:key1].should be_nil
        end

        it "raise an exception if accessed like property" do
          lambda {
            @simple_struct.key1
          }.should raise_error
        end
      end
    end

    describe "write" do
      it "index - like" do
        @simple_struct[:key] = "value1"
        @simple_struct[:key].should == "value1"

        @simple_struct[:str_key] = "value1"
        @simple_struct[:str_key].should == "value1"
      end

      it "does not depends on key type" do
        @simple_struct["key"] = "value1"
        @simple_struct[:key].should == "value1"

        @simple_struct["str_key"] = "value1"
        @simple_struct[:str_key].should == "value1"
      end

      it "as property" do
        @simple_struct.key = "value1"
        @simple_struct.key.should == "value1"
        @simple_struct[:key].should == "value1"

        @simple_struct.str_key = "value1"
        @simple_struct.str_key.should == "value1"
        @simple_struct[:str_key].should == "value1"
      end
    end
  end

  
end

